@@ -1,7 +1,7 @@
 from pathlib import Path
 
+from cdflib.cdfread import CDF
 from . import cdfread, cdfwrite
-from .cdf_factory import CDF
 from .epochs import CDFepoch as cdfepoch  # noqa: F401
 
 try:
@@ -10,11 +10,12 @@ try:
 except BaseException:
     pass
 
-try:
-    # Another optional dependency for XArray <-> cdf conversions
-    from .cdf_to_xarray import cdf_to_xarray
-    from .xarray_to_cdf import xarray_to_cdf
-except BaseException:
-    pass
+# Another optional dependency for XArray <-> cdf conversions
+from .cdf_to_xarray import cdf_to_xarray
+from .xarray_to_cdf import xarray_to_cdf
 
 __all__ = ['CDF', 'xarray_to_cdf', 'cdf_to_xarray']
+try:
+    from .version import version as __version__
+except Exception:
+    __version__ = 'unknown'
