@@ -197,7 +197,7 @@ class CDFAstropy:
             epoch16strings = [epoch16strings]
         times = []
         for t in epoch16strings:
-            time_as_list = []
+            time_as_list: List[int] = []
             date, time = t.split(" ")
             yyyy, mon, dd = date.split("-")
             hhmmss, decimal_seconds = time.split(".")
@@ -287,11 +287,3 @@ class CDFAstropy:
             return time_list
         else:
             return np.array(time_list)
-
-    @staticmethod
-    def getVersion():
-        """
-        Prints the code version.
-        """
-        print('epochs version:', str(CDFAstropy.version) + '.' +
-              str(CDFAstropy.release) + '.' + str(CDFAstropy.increment))
